@@ -1,7 +1,7 @@
 /*
  * libev select fd activity backend
  *
- * Copyright (c) 2007,2008,2009 Marc Alexander Lehmann <libev@schmorp.de>
+ * Copyright (c) 2007,2008 Marc Alexander Lehmann <libev@schmorp.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modifica-
@@ -54,8 +54,6 @@
 #if EV_SELECT_IS_WINSOCKET
 # undef EV_SELECT_USE_FD_SET
 # define EV_SELECT_USE_FD_SET 1
-# undef NFDBITS
-# define NFDBITS 0
 #endif
 
 #if !EV_SELECT_USE_FD_SET
@@ -79,26 +77,15 @@ select_modify (EV_P_ int fd, int oev, int nev)
     int handle = fd;
     #endif
 
-    assert (("libev: fd >= FD_SETSIZE passed to fd_set-based select backend", fd < FD_SETSIZE));
+    if (nev & EV_READ)
+      FD_SET (handle, (fd_set *)vec_ri);
+    else
+      FD_CLR (handle, (fd_set *)vec_ri);
 
-    /* FD_SET is broken on windows (it adds the fd to a set twice or more,
-     * which eventually leads to overflows). Need to call it only on changes.
-     */
-    #if EV_SELECT_IS_WINSOCKET
-    if ((oev ^ nev) & EV_READ)
-    #endif
-      if (nev & EV_READ)
-        FD_SET (handle, (fd_set *)vec_ri);
-      else
-        FD_CLR (handle, (fd_set *)vec_ri);
-
-    #if EV_SELECT_IS_WINSOCKET
-    if ((oev ^ nev) & EV_WRITE)
-    #endif
-      if (nev & EV_WRITE)
-        FD_SET (handle, (fd_set *)vec_wi);
-      else
-        FD_CLR (handle, (fd_set *)vec_wi);
+    if (nev & EV_WRITE)
+      FD_SET (handle, (fd_set *)vec_wi);
+    else
+      FD_CLR (handle, (fd_set *)vec_wi);
 
 #else
 
@@ -140,7 +127,6 @@ select_poll (EV_P_ ev_tstamp timeout)
   int res;
   int fd_setsize;
 
-  EV_RELEASE_CB;
   tv.tv_sec  = (long)timeout;
   tv.tv_usec = (long)((timeout - (ev_tstamp)tv.tv_sec) * 1e6);
 
@@ -161,13 +147,9 @@ select_poll (EV_P_ ev_tstamp timeout)
    */
   memcpy (vec_eo, vec_wi, fd_setsize);
   res = select (vec_max * NFDBITS, (fd_set *)vec_ro, (fd_set *)vec_wo, (fd_set *)vec_eo, &tv);
-#elif EV_SELECT_USE_FD_SET
-  fd_setsize = anfdmax < FD_SETSIZE ? anfdmax : FD_SETSIZE;
-  res = select (fd_setsize, (fd_set *)vec_ro, (fd_set *)vec_wo, 0, &tv);
 #else
   res = select (vec_max * NFDBITS, (fd_set *)vec_ro, (fd_set *)vec_wo, 0, &tv);
 #endif
-  EV_ACQUIRE_CB;
 
   if (expect_false (res < 0))
     {
@@ -186,7 +168,7 @@ select_poll (EV_P_ ev_tstamp timeout)
       #ifdef _WIN32
       /* select on windows errornously returns EINVAL when no fd sets have been
        * provided (this is documented). what microsoft doesn't tell you that this bug
-       * exists even when the fd sets _are_ provided, so we have to check for this bug
+       * exists even when the fd sets are provided, so we have to check for this bug
        * here and emulate by sleeping manually.
        * we also get EINVAL when the timeout is invalid, but we ignore this case here
        * and assume that EINVAL always means: you have to wait manually.
@@ -203,7 +185,7 @@ select_poll (EV_P_ ev_tstamp timeout)
       else if (errno == ENOMEM && !syserr_cb)
         fd_enomem (EV_A);
       else if (errno != EINTR)
-        ev_syserr ("(libev) select");
+        syserr ("(libev) select");
 
       return;
     }
@@ -272,6 +254,7 @@ select_init (EV_P_ int flags)
   backend_poll   = select_poll;
 
 #if EV_SELECT_USE_FD_SET
+  vec_max = FD_SETSIZE / 32;
   vec_ri  = ev_malloc (sizeof (fd_set)); FD_ZERO ((fd_set *)vec_ri);
   vec_ro  = ev_malloc (sizeof (fd_set));
   vec_wi  = ev_malloc (sizeof (fd_set)); FD_ZERO ((fd_set *)vec_wi);
